%% INPUT DATA
%% Fresh start
close all, clc, clearvars -except data1 PV_kWp1
[filename, pathname] = uigetfile({'*.xlsx';'*.xls'},'File Selector');
 
%% check if Load/PV data has been loaded
if ~exist('load', 'var'), 
    import_data_company;
    v = 1;
    t(:,1) = v * (1:size(t));
    load(:,1) = t(:,1);
    load(:,2) = LoadkW(:,1);
end

% Construct a questdlg with three options
pvexist = questdlg('Do you have any PV data to introduce into the model?',...
    'PV Data','Yes','No', 'Cancel','Cancel');
% Handle response
switch pvexist
    case 'Yes'
         temporal00 = {'Introduce the solar power of your system (kWp):'};
         dlg_title = 'Enter the following data     ';
         num_lines = 1;
         if exist('PV_kWp1','var'),  
             def = PV_kWp1;
             PV_kWp1 = inputdlg(temporal00,dlg_title,num_lines,def); 
         else 
             PV_kWp1 = inputdlg(temporal00,dlg_title,num_lines); 
         end
         PV_kWp = str2num(cell2mat(PV_kWp1));
         if ~exist('PV_power', 'var')
             PV_power(:,1) = t(:,1);  
             PV_power(:,2) = PVkW(:,1);  
         end
    case 'No'
         if ~exist('PV_power', 'var')
             PV_power(:,1) = t(:,1); 
             PV_power(:,2) = (0);
         end
    case 'Cancel'
         h = msgbox('Simulation canceled');
         error('The simulation has been canceled');
end

%% Define the variables
% Construct a questdlg with three options
answer = questdlg('Would you like to simulate with the default values?', ...
    'Default Values','Yes','No','Cancel','Cancel');
% Handle response
if strcmp(answer, 'Yes')
     temporal0 = {'Time step (minutes) between each data of the load:'};
     dlg_title = 'Enter the following data     ';
     num_lines = 1;
     def1 ={'15'};
     T1 = inputdlg(temporal0,dlg_title,num_lines,def1);  
     T = str2num(cell2mat(T1)); 
     T = T * 60;
     SOC_initial = 80;
     maximum = 1000 * max(load(:,2));
     average = 1000 * mean(load(:,2));
     difference = maximum - average;
         
elseif strcmp(answer, 'No')      
    temporal = {'Time step (minutes) between each data of the load:',
    'Batterys initial state of charge (SOC), between 0 and 100:',
    'Minimum SOC to which the battery may be discharged, between 0 and 100:',
    'Nominal battery voltage (V):',
    'Nominal battery capacity (kWh):',
    'Charge rate (CR):',
    'Discharge rate (DR):',
    'Investment of the battery (). To calculate it with the program, write 0:',
    'Maximum desired power grid (kW):',
    'Nominal electric CHP power (kW):',
    'Electric efficiency of CHP (%). A suitable value would be around 38:'};
    dlg_title = 'Enter the following data     ';
    num_lines = 1;
    if exist('data1','var'),  
         def2 = data1;
         data1 = inputdlg(temporal,dlg_title,num_lines,def2); 
    else 
         data1 = inputdlg(temporal,dlg_title,num_lines); 
    end
    if isempty (data1)
        h = msgbox('Simulation Canceled');
        error('your quitting error message');
    end
    Data = str2double(data1);
    T = Data(1) * 60;
    SOC_initial = Data(2);
    SOC_min = Data(3);
    SOC_min = SOC_min/100;
    if SOC_min < 0.00011
        SOC_min = 0.00011;
    end  
    nominal_battery_voltage = Data(4);
    battery_capacity = Data(5)/nominal_battery_voltage*1000;
    c_charge = Data(6);
    c_discharge = Data(7);
    battery_investment_user = Data(8);
    max_desired_power_grid = Data(9);
    CHP_max = Data(10);
    CHP_electric_efficiency = Data(11)/100;
    max_desired_power_grid = max_desired_power_grid * 1000;
    CHP_max = CHP_max * 1000;
    nominal_discharge_battery_current=c_discharge*battery_capacity;
    max_discharge_power=nominal_battery_voltage*nominal_discharge_battery_current;
    nominal_charge_battery_current=c_charge*battery_capacity;
    max_charge_power=nominal_battery_voltage*nominal_charge_battery_current;

else strcmp(answer, 'Cancel')
    h = msgbox('Simulation canceled');
    error('your quitting error message');
end

h = waitbar(0,'Please wait...(To abort process, press Ctrl+C)');
