%% PRICES 2
kWh = 1/(3600*1000);

%% GRID TO PROVIDE ALL THE LOAD
%  Power
grid_power_price = 63; % /kW
maximum_value_load = max(load_W.Data)/1000;
grid_to_load_total_power_cost = grid_power_price * maximum_value_load ...
    /365 *number_days;

%  Energy
grid_energy_price = 0.15; % /kWh
grid_to_load_total_energy_cost = 0;
for n=2:length(load_W.Data)
    a = n-1;
    grid_to_load_total_energy_cost = grid_to_load_total_energy_cost ...
        +T * load_W.Data(n) * (load_W.Time(n) - load_W.Time(a));
end
grid_to_load_total_energy_cost = grid_to_load_total_energy_cost ...
    * kWh * grid_energy_price;

pay_grid_provide_all = grid_to_load_total_power_cost ...
    + grid_to_load_total_energy_cost;

%% GRID
%  Grid power
grid_power_price = 63; % /kW
maximum_value_grid = max(grid_supply.Data)/1000;
grid_total_power_cost = grid_power_price * maximum_value_grid ...
    /365 *number_days;

%  Grid energy
grid_energy_price = 0.15; % /kWh
grid_total_energy_cost = 0;
for n=2:length(grid_supply.Data)
    a = n-1;
    grid_total_energy_cost = grid_total_energy_cost ...
        +T *grid_supply.Data(n) *(grid_supply.Time(n) - grid_supply.Time(a));
end
grid_total_energy_cost = grid_total_energy_cost * kWh * grid_energy_price;

%%  BATTERY
if battery_investment_user == 0
    battery_capacity_kWh = battery_capacity/1000*nominal_battery_voltage;
    battery_investment_user = 5555.6*battery_capacity_kWh^0.784;
end

if strcmp(battery_type, 'lead acid')
    battery_investment_user = battery_investment_user/7;
end

%% CHP
% CHP investment
CHP_investment = CHP_max/1000 * (9332.6*(CHP_max/1000)^-0.4611);

% CHP surplus
feed_in_price_CHP = 0.105; % /kWh
CHP_total_surplus_benefit = 0;
for n=2:length(CHP_surplus.Data)
    a = n-1;
    CHP_total_surplus_benefit = CHP_total_surplus_benefit ...
        +T *CHP_surplus.Data(n) *(CHP_surplus.Time(n) - CHP_surplus.Time(a));
end
CHP_total_surplus_benefit = CHP_total_surplus_benefit * kWh * feed_in_price_CHP;

% CHP electricity and heat prices
Top = 8000; % Operation time per year (h/a)
CHP_heat_power = CHP_max * 1.2;
CHP_heat_efficiency = 0.49;
% Heat energy produced in a year (kWhth/a)
Eh = CHP_heat_power/1000 * Top * CHP_heat_efficiency;
gas_boiler_efficiency = 0.9;
gas_price = 0.045; % /kWh
heat_price = gas_price / gas_boiler_efficiency; % /kWhth
% Electric energy produced in a year (kWhe/a)
Ee = CHP_max/1000 * Top * CHP_electric_efficiency;
Ta = 2; % Amortization time, payback time of the investment
Cop = 2.3133/100 * (CHP_max/1000)^-0.141; % Operational annual cost (/kWhe)
CHP_electricity_price = (CHP_investment/Ta + Cop*Ee - Eh*heat_price)/Ee; % /kWhe
CHP_total_electric_cost = T*CHP_max*length(load)*kWh*CHP_electricity_price;
CHP_total_heat_cost = T*CHP_heat_power*length(load)*kWh*heat_price;

pay_grid_batt_and_CHP = grid_total_power_cost + grid_total_energy_cost ...
    + CHP_total_electric_cost - CHP_total_surplus_benefit;
investment_grid_batt_and_CHP = battery_investment_user + CHP_investment;
pay_back_grid_batt_and_CHP = investment_grid_batt_and_CHP ...
    /((pay_grid_provide_all - pay_grid_batt_and_CHP)*365/number_days);

%% PV
if strcmp(pvexist, 'Yes')
% PV investment
    PV_price = 1250; % /kWp
    PV_investment = PV_price * PV_kWp; 
% PV surplus   
    feed_in_price_PV = 0.11; % /kWh
    PV_total_surplus_benefit = 0;
    for n=2:length(PV_surplus.Data)
        a = n-1;
        PV_total_surplus_benefit = PV_total_surplus_benefit ...
            +T *PV_surplus.Data(n) *(PV_surplus.Time(n) - PV_surplus.Time(a));
    end
    PV_total_surplus_benefit = PV_total_surplus_benefit *kWh *feed_in_price_PV;
    pay_grid_batt_CHP_and_PV = pay_grid_batt_and_CHP -PV_total_surplus_benefit;
    investment_grid_batt_CHP_and_PV = investment_grid_batt_and_CHP +PV_investment;
    pay_back_grid_batt_CHP_and_PV = investment_grid_batt_CHP_and_PV ...
        /((pay_grid_provide_all - pay_grid_batt_CHP_and_PV)*365/number_days);
end
