%% PROGRAM RESULTS
% graphs
hl = figure;
set(hl,'visible','off');
if strcmp(pvexist, 'Yes')
    X = load_W.Time*T/3600;
    grid_new = grid_supply.Data - char_battery.Data;
    Y = [CHP.Data,grid_new,char_battery.Data,PV.Data, ...
    dis_battery.Data]/1000;
    subplot (20,1,[1 13]);
    harea = area(X, Y);
    x_step_tick = number_days * 2.5;
    set(gca, 'XTick', [0:x_step_tick:length(load)])
    set(harea(2),'FaceColor',[0 .9 1]);
    set(harea(3),'FaceColor',[0 .5 0]);
    set(harea(4),'FaceColor',[1 .8 0]);
    set(harea(5),'FaceColor',[.5 .1 .1]);
    title ('Power Balance','FontSize', 12,'FontWeight','bold')
    xlabel('Time (h)','FontSize', 10)
    ylabel('Power (kW)','FontSize', 10)
    hleg1 = legend('CHP','Grid - Charge Battery', ...
        'Charge Battery','PV','Discharge Battery');
    set(hleg1,'FontSize', 7,'Location','SouthEast')
else
    X = load_W.Time*T/3600;
    grid_new = grid_supply.Data - char_battery.Data;
    Y = [CHP.Data,grid_new,char_battery.Data,dis_battery.Data]/1000;
    subplot (20,1,[1 13]);
    harea = area(X, Y);
    x_step_tick = number_days * 2.5;
    set(gca, 'XTick', [0:x_step_tick:length(load)])
    set(harea(3),'FaceColor',[0 .5 0]);
    title ('Power Balance','FontSize', 12,'FontWeight','bold')
    xlabel('Time (h)','FontSize', 10)
    ylabel('Power (kW)','FontSize', 10)
    hleg2 = legend('CHP','Grid - Charge Battery','Charge Battery', ...
        'Discharge Battery');
    set(hleg2,'FontSize', 7,'Location','SouthEast')
end
grid on

subplot (20,1,[17 20])
plot(SOC)
xlim([0 length(load)])
x_step_tick = number_days * 10;
set(gca, 'XTick', [0:x_step_tick:length(load)])
x_step_label = number_days*2.5;
set(gca,'XTickLabel',[0;x_step_label;2*x_step_label; ...
    3*x_step_label;4*x_step_label;5*x_step_label; ...
    6*x_step_label;7*x_step_label;8*x_step_label;9*x_step_label])
ylim([0 1])
set(gca,'YTick',[0;0.2;0.4;0.6;0.8;1])
title ('Battery State Of Charge','FontSize', 12,'FontWeight','bold')
xlabel('Time (h)','FontSize', 10)
ylabel('SOC','FontSize', 10)
grid on

mkdir('RESULTS WITH DEFAULT DATA');
saveas(hl,['Power_Balance CHP' num2str(run) '_Battery' ...
    num2str(sub_run)],'jpg');
movefile('*.jpg','RESULTS WITH DEFAULT DATA');

% text in Excel
header = {'','Recommended Battery Type',battery_type};
classinfo = {'Parameters','Values','Units'; 'Time Step',T/60,'min'; ...
    'Initial SOC',SOC_initial,'%'; 'Minimum SOC',SOC_min*100,'%'; ...
    'Nominal Battery Voltage',nominal_battery_voltage,'V'; ...
    'Battery Capacity',battery_capacity*nominal_battery_voltage/1000, ...
    'kWh'; 'Charge Rate',c_charge,'1/h'; ...
    'Discharge Rate',c_discharge,'1/h'; ...
    'Maximum Discharge Power of the Battery',max_discharge_power/1000, ...
    'kW'; 'Maximum Desired Power Grid',max_desired_power_grid/1000,'kW'; ...
    'Nominal el. CHP Power',CHP_max/1000,'kW'; ...
    'CHP electric efficiency',CHP_electric_efficiency*100,'%'; ...
    'CHP heat Power',CHP_heat_power/1000,'kW'; ...
    'CHP heat efficiency',CHP_heat_efficiency*100,'%'; ...
    'Number of days',number_days,'days'};
headergridtoload = {'GRID TO PROVIDE ALL LOAD'};
gridpricetoload = {'Power','','',''; '','Parameters','Values','Units'; ...
    '','Power Price',63,'/kW'; '','Max. Value',maximum_value_load,'kW'; ...
    '','Total Power Price',grid_to_load_total_power_cost,''; ...
    'Energy','','',''; '','Parameters','Values','Units'; ...
    '','Energy Price',0.15,'/kWh'; ...
    '','Total Energy Price',grid_to_load_total_energy_cost,''};
headergrid = {'GRID'};
gridprice = {'Power','','',''; '','Parameters','Values','Units'; ...
    '','Power Price',63,'/kW'; '','Max. Value',maximum_value_grid,'kW'; ...
    '','Total Power Price',grid_total_power_cost,''; ...
    'Energy','','',''; '','Parameters','Values','Units'; ...
    '','Energy Price',0.15,'/kWh'; ...
    '','Total Energy Price',grid_total_energy_cost,''};
if strcmp(pvexist, 'Yes')
    headerPV = {'PV'};
    PVprice = {'Investment','','',''; '','Parameters','Values','Units'; ...
        '','PV Price',PV_investment,''; 'Surplus','','',''; ...
        '','Parameters','Values','Units'; '','Feed in Price',0.1,'/kWh'; ...
        '','Total Surplus Price',PV_total_surplus_benefit,''};
end
headerbattery = {'BATTERY'};
batteryprice = {'Parameters','Values','Units'; ...
    'Battery Price',battery_investment,''};
headerCHP = {'CHP'};
CHPprice = {'Investment','','',''; '','Parameters','Values','Units'; ...
    '','CHP Price',CHP_investment,''; 'Surplus','','',''; ...
    '','Parameters','Values','Units'; '','Feed in Price',0.105,'/kWh'; ...
    '','Total Surplus Price',CHP_total_surplus_benefit,''; ...
    'Electricity and Heat','','',''; '','Parameters','Values','Units'; ...
    '','Electricity Price',CHP_electricity_price,'/kWh'; ...
    '','Total Electric Price',CHP_total_electric_cost,''; ...
    '','Heat Price',heat_price,'/kWh'; ...
    '','Total Heat Price',CHP_total_heat_cost,''};
summary = {'','SUMMARY',''; '','',''; 'GRID SUPPLIES ALL LOAD','',''; ...
    'MONEY TO PAY',pay_grid_provide_all,''};
if strcmp(pvexist, 'No')
    summary2 = {'GRID WITH BATT AND CHP','',''; ...
        'MONEY TO PAY',pay_grid_batt_and_CHP,''; ...
        'INVESTMENT',investment_grid_batt_and_CHP,''};
    summary3 = {'PAY-BACK',pay_back_grid_batt_and_CHP,'years'};
end
if strcmp(pvexist, 'Yes')
    summary2 = {'GRID WITH BATT, CHP AND PV','',''; ...
        'MONEY TO PAY',pay_grid_batt_CHP_and_PV,''; ...
        'INVESTMENT',investment_grid_batt_CHP_and_PV,''};
    summary3 = {'PAY-BACK',pay_back_grid_batt_CHP_and_PV,'years'};
end

xlswrite(['CHP_' num2str(run)],header,...
    ['battery ' num2str(sub_run)]);
xlswrite(['CHP_' num2str(run)],classinfo,...
    ['battery ' num2str(sub_run)],'B3');
xlswrite(['CHP_' num2str(run)],headergridtoload,...
    ['battery ' num2str(sub_run)],'B19');
xlswrite(['CHP_' num2str(run)],gridpricetoload,...
    ['battery ' num2str(sub_run)],'C20');
xlswrite(['CHP_' num2str(run)],headergrid,...
    ['battery ' num2str(sub_run)],'H1');
xlswrite(['CHP_' num2str(run)],gridprice,...
    ['battery ' num2str(sub_run)],'I2');
if strcmp(pvexist, 'Yes')
    xlswrite(['CHP_' num2str(run)],headerPV,...
        ['battery ' num2str(sub_run)],'H31');
    xlswrite(['CHP_' num2str(run)],PVprice,...
        ['battery ' num2str(sub_run)],'I32');
end
xlswrite(['CHP_' num2str(run)],headerbattery,...
    ['battery ' num2str(sub_run)],'H12');
xlswrite(['CHP_' num2str(run)],batteryprice,...
    ['battery ' num2str(sub_run)],'I13');
xlswrite(['CHP_' num2str(run)],headerCHP,...
    ['battery ' num2str(sub_run)],'H16');
xlswrite(['CHP_' num2str(run)],CHPprice,...
    ['battery ' num2str(sub_run)],'I17');
xlswrite(['CHP_' num2str(run)],summary,...
    ['battery ' num2str(sub_run)],'N1');
xlswrite(['CHP_' num2str(run)],summary2,...
    ['battery ' num2str(sub_run)],'N6');
xlswrite(['CHP_' num2str(run)],summary3,...
    ['battery ' num2str(sub_run)],'N10'); 

if run == 2 && sub_run == 20
    movefile('*.xls','RESULTS WITH DEFAULT DATA');
    steps = 1000;
    for step = 1:steps
        waitbar(step / steps)
    end
    close(h)
    msgbox('Simulation Completed','Success');
end
    